@@ -12,6 +12,9 @@
 #if __GLASGOW_HASKELL__ >= 710 && __GLASGOW_HASKELL__ < 802
 {-# LANGUAGE AutoDeriveTypeable #-}
 #endif
+#if __GLASGOW_HASKELL__ >= 710
+{-# LANGUAGE DeriveAnyClass #-}
+#endif
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Data.FingerTree
@@ -30,7 +33,7 @@
 --  * Ralf Hinze and Ross Paterson,
 --    \"Finger trees: a simple general-purpose data structure\",
 --    /Journal of Functional Programming/ 16:2 (2006) pp 197-217.
---    <http://staff.city.ac.uk/~ross/papers/FingerTree.html>
+--    <https://staff.city.ac.uk/~ross/papers/FingerTree.html>
 --
 -- For a directly usable sequence type, see @Data.Sequence@, which is
 -- a specialization of this structure.
@@ -87,11 +90,14 @@ import qualified Prelude (null)
 #else
 import Control.Applicative (Applicative(pure, (<*>)), (<$>))
 import Data.Monoid
+#endif
+#if !(MIN_VERSION_base(4,8,0)) || defined(__MHS__)
 import Data.Foldable (Foldable(foldMap))
 #endif
 #if (MIN_VERSION_base(4,9,0)) && !(MIN_VERSION_base(4,11,0))
 import Data.Semigroup
 #endif
+import Control.DeepSeq
 import Data.Foldable (toList)
 
 infixr 5 ><
@@ -105,6 +111,9 @@ data ViewL s a
     deriving (Eq, Ord, Show, Read
 #if __GLASGOW_HASKELL__ >= 706
         , Generic
+#if __GLASGOW_HASKELL__ >= 710
+        , NFData
+#endif
 #endif
         )
 
@@ -116,6 +125,9 @@ data ViewR s a
     deriving (Eq, Ord, Show, Read
 #if __GLASGOW_HASKELL__ >= 706
         , Generic
+#if __GLASGOW_HASKELL__ >= 710
+        , NFData
+#endif
 #endif
         )
 
@@ -149,6 +161,9 @@ data Digit a
     deriving (Show
 #if __GLASGOW_HASKELL__ >= 706
         , Generic
+#if __GLASGOW_HASKELL__ >= 710
+        , NFData
+#endif
 #endif
         )
 
@@ -177,6 +192,9 @@ data Node v a = Node2 !v a a | Node3 !v a a a
     deriving (Show
 #if __GLASGOW_HASKELL__ >= 706
         , Generic
+#if __GLASGOW_HASKELL__ >= 710
+        , NFData
+#endif
 #endif
         )
 
@@ -217,8 +235,13 @@ data FingerTree v a
     deriving (Show
 #if __GLASGOW_HASKELL__ >= 706
         , Generic
+#if __GLASGOW_HASKELL__ >= 710
+        , NFData
+#endif
 #endif
         )
+#elif __GLASGOW_HASKELL__ >= 710
+    deriving (Generic, NFData)
 #elif __GLASGOW_HASKELL__ >= 706
     deriving (Generic)
 #endif
@@ -871,6 +894,8 @@ digitToTree (Four a b c d) = deep (Two a b) Empty (Two c d)
 (><) :: (Measured v a) => FingerTree v a -> FingerTree v a -> FingerTree v a
 (><) =  appendTree0
 
+-- appendTree<0..4> and addDigits<0..4> were generated by misc/mkappend.hs
+
 appendTree0 :: (Measured v a) => FingerTree v a -> FingerTree v a -> FingerTree v a
 appendTree0 Empty xs =
     xs
@@ -1126,6 +1151,9 @@ data SearchResult v a
     deriving (Eq, Ord, Show
 #if __GLASGOW_HASKELL__ >= 706
         , Generic
+#if __GLASGOW_HASKELL__ >= 710
+        , NFData
+#endif
 #endif
         )
 
